<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Master Layout</title>
    <link rel="stylesheet" href="<?php echo e(asset('css/app.css')); ?>">
    <style>
        body, html {
            height: 100%;
            margin: 0;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            display: flex;
            height: 100vh;
        }
        .sidebar {
            width: 250px;
            background-color: #000;
            color: #fff;
            display: flex;
            flex-direction: column;
            padding: 20px;
            border-right: 2px solid #444;
            position: relative; /* Position relative for logout button placement */
        }
        .sidebar img {
            max-width: 100%;
            margin-bottom: 30px;
        }
        .sidebar select {
            width: 100%;
            padding: 10px;
            margin-bottom: 20px;
            background-color: #1a1a1a;
            color: #fff;
            border: 1px solid #555;
            border-radius: 4px;
            font-size: 14px;
        }
        .sidebar select option {
            background-color: #1a1a1a;
            color: #fff;
        }
        .sidebar h3 {
            margin-bottom: 10px;
            font-size: 16px;
            font-weight: 600;
            color: #ddd;
        }
        .main-content {
            flex-grow: 1;
            padding: 20px;
            background-color: #fff;
            color: #000;
            display: flex;
            justify-content: center; /* Center content horizontally */
            align-items: center; /* Center content vertically */
            text-align: center; /* Center text */
        }
        .message {
            font-size: 24px; /* Increase font size */
            color: #555; /* Grey color for the message */
        }
        .logout-button {
            margin-top: auto; /* Push the button to the bottom */
            padding: 10px;
            background-color: #dc3545; /* Bootstrap's danger color */
            color: #fff;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            text-align: center;
            transition: background-color 0.3s;
        }
        .logout-button:hover {
            background-color: #c82333; /* Darker shade on hover */
        }
    </style>
</head>
<body>
    <div class="container">
        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Logo -->
            <img src="<?php echo e(asset('uploads/revcal.png')); ?>" alt="Logo">
            
            <!-- Revenue Plan Type Heading -->
            <h3>Revenue Plan Type</h3>
            <!-- Revenue Plan Type Select -->
            <select id="revenue-plan-type">
                <option value="" disabled selected>Select Plan Type</option>
                <option value="daily">Daily Plan</option>
                <option value="fixed">Fixed Plan</option>
            </select>

            <!-- Revenue Recognition Rule Heading -->
            <h3>Revenue Recognition Rule</h3>
            <!-- Revenue Recognition Rule Select as Routes -->
            <select id="revenue-recognition-rule" onchange="routeToFile()">
                <option value="" disabled selected>Select Recognition Rule</option>
                <option value="relatable" <?php echo e(request()->is('relatable') ? 'selected' : ''); ?>>Relatable</option>
                <option value="point-in-time" <?php echo e(request()->is('point-intime') ? 'selected' : ''); ?>>Point in Time</option>
            </select>

            <!-- Logout Button -->
            <button class="logout-button" onclick="logout()">Logout</button>
        </div>

        <!-- Main content area -->
        <div class="main-content">
            <?php if(request()->is('revcal')): ?> <!-- Check for the correct route -->
                <div class="message">
                    Choose a plan to proceed.
                </div>
            <?php else: ?>
                <?php echo $__env->yieldContent('content'); ?> <!-- Include the content section for other routes -->
            <?php endif; ?>
        </div>
    </div>

    <script>
        function routeToFile() {
            let rule = document.getElementById('revenue-recognition-rule').value;

            if (rule === 'relatable') {
                window.location.href = '/relatable'; // Redirect to Relatable page
            } else if (rule === 'point-in-time') {
                window.location.href = '/point-intime'; // Redirect to Point in Time page
            }
        }

        function logout() {
            window.location.href = '/loginform'; // Redirect to login form
        }
    </script>
</body>
</html>
<?php /**PATH /home/eigixn5/public_html/standman/resources/views/Revcal/master.blade.php ENDPATH**/ ?>